@@ -27,6 +27,7 @@
 
 
 
+import base64
 import json
 import datetime
 import argtoolbox
@@ -46,8 +47,19 @@ class DefaultCommand(common.DefaultCommand):
     def __get_cli_object(self, args):
         api_version = self.config.server.api_version.value
         self.log.debug("using api version : " + str(api_version))
-        cli = AdminCli(args.host, args.user, args.password, args.verbose,
-                       args.debug, api_version=api_version, verify=getattr(args, 'verify', True))
+        auth_type = args.auth_type
+        password = args.password
+        self.log.debug("auth_type: %s", auth_type)
+        self.log.debug("password: %s...", password[0:2])
+        if auth_type == "plain-b64":
+            if password:
+                self.log.debug("converting base64 encoded password to plain text.")
+                password = base64.b64decode(password).decode('utf-8')
+            auth_type = "plain"
+        cli = AdminCli(args.host, args.user, password, args.verbose,
+                       args.debug, api_version=api_version,
+                       verify=getattr(args, 'verify', True),
+                      auth_type=auth_type)
         if args.base_url:
             cli.base_url = args.base_url
         return cli
